package main

import (
	"database/sql"
	"log"

	_ "github.com/go-sql-driver/mysql"
)

func main() {
	// 格式有对应的驱动定义
	// user:password@tcp(host:port)/database?charset=utf8mb4&loc=PRC&parseTime=true
	dataSourceName := "root:root@tcp(100.80.0.128:3306)/golangdev?charset=utf8mb4&loc=PRC&parseTime=true"
	db, err := sql.Open("mysql", dataSourceName)
	if err != nil {
		log.Fatal(err)
		return
	}
	log.Println(db)

	// 测试连接状态
	log.Println(db.Ping())

	// 执行
	// 创建数据库
	_, err = db.Exec(`create table if not exists test(
	    id bigint primary key auto_increment,
	    name varchar(32) not null comment "test name"
	) engine=innodb default charset utf8mb4;`)
	if err != nil {
		log.Println(err)
	}

	// 插入
	result, err := db.Exec(`insert into test(name) value ("xiexianbin");`)
	if err != nil {
		log.Println(err)
	}
	log.Println(result.LastInsertId())
	log.Println(result.RowsAffected())

	// 读
	result, err = db.Exec(`show tables;`)
	if err != nil {
		log.Println(err)
	}
	log.Println(result.LastInsertId())
	log.Println(result.RowsAffected())

	// 更新
	result, err = db.Exec(`update test set name = ? where name = ?;`, "xianbin", "xiexianbin")
	log.Println(err)
	log.Println(result.LastInsertId())
	log.Println(result.RowsAffected())

	// 删除
	result, err = db.Exec(`delete from test where name = ?;`, "xiexianbin")
	if err != nil {
		log.Println(err)
	} else {
		log.Println(result.LastInsertId())
		log.Println(result.RowsAffected())
	}

	// 查询
	var (
		id   int
		name string
	)

	var line struct {
		Id   int
		Name string
	}

	sql := `select id, name from test where id > ? order by id desc;`
	rows, err := db.Query(sql, 1)
	if err != nil {
		log.Println(err)
	} else {
		for rows.Next() {
			err = rows.Scan(&line.Id, &line.Name)
			log.Println("line", line.Id, line.Name)
		}
	}

	row := db.QueryRow(sql, 4)
	err = row.Scan(&id, &name)
	if err != nil {
		log.Println(err)
	}
	log.Println(id, name)
}
